@@ -1,7 +1,7 @@
 from sys import path
 from pathlib import Path
 path.append(str(Path(__file__).parent.resolve()))
-from JfifDecoder import decode as JFIF_decoder
+from JFIFDecoder import decode as JFIF_decoder
 from Image_reader import Image_reading_class as Image_reader
 
 from numpy import asarray, ndarray
@@ -17,7 +17,6 @@ def read_image(path: str) -> ndarray:
     file_test = image.read_str(JFIF_FILE_TEST_SIZE)
     if file_test.startswith(b'\xff\xd8\xff\xe0') and file_test.endswith(b'JFIF\x00'): #signature of JFIF format
         image.read(file_test[5] - JFIF_FILE_TEST_SIZE)
-        print("That`s a JFIF FILE!")
         try:
             raw_img = JFIF_decoder(image)
         except:
